package cn.iocoder.yudao.module.shop.service;

import java.util.List;
import cn.iocoder.yudao.module.shop.entity.ShopUserCar;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.tencentcloudapi.common.exception.TencentCloudSDKException;

/**
 * 用户车辆Service接口
 *
 * @author ruoyi
 * @date 2023-07-10
 */
public interface IShopUserCarService extends IService<ShopUserCar>
{
    /**
     * 查询用户车辆
     *
     * @param carId 用户车辆主键
     * @return 用户车辆
     */
    public ShopUserCar selectShopUserCarByCarId(Long carId);

    /**
     * 查询用户车辆列表
     *
     * @param shopUserCar 用户车辆
     * @return 用户车辆集合
     */
    public IPage<ShopUserCar> selectShopUserCarList(Page<ShopUserCar> page, ShopUserCar shopUserCar);

    /**
     * 新增用户车辆
     *
     * @param shopUserCar 用户车辆
     * @return 结果
     */
    public int insertShopUserCar(ShopUserCar shopUserCar);

    /**
     * 修改用户车辆
     *
     * @param shopUserCar 用户车辆
     * @return 结果
     */
    public int updateShopUserCar(ShopUserCar shopUserCar);

    /**
     * 批量删除用户车辆
     *
     * @param carIds 需要删除的用户车辆主键集合
     * @return 结果
     */
    public int deleteShopUserCarByCarIds(Long[] carIds);

    /**
     * 删除用户车辆信息
     *
     * @param carId 用户车辆主键
     * @return 结果
     */
    public int deleteShopUserCarByCarId(Long carId);

    public ShopUserCar selectShopUserCarByUserId(Long userId);
    ShopUserCar selectUserCarsByUserIdCarNum(Long userId,String carNum);

    List<ShopUserCar> selectUserCarsByUserId(Long userId);
    List<ShopUserCar> getDbCars(Long userId);

    String vehicleLicenseOCR(String imagePath) throws TencentCloudSDKException;
    String appVehicleLicenseOCR(String imagePath) throws Exception;
    JSONObject appVehicleLicenseOCR2(String imagePath) throws Exception;
    void infoCardOCR( String imagePath) throws TencentCloudSDKException;
    JSONObject getInfoCard();

    void deleteShopUserCarByUserId(Long userId);
}
